import { EventEmitter, OnChanges, OnInit, SimpleChanges, TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A context for the
 * * `NgbPaginatorFirst`
 * * `NgbPaginatorPrevious`
 * * `NgbPaginatorNext`
 * * `NgbPaginatorLast`
 * * `NgbPaginatorEllipsis`
 * * `NgbPaginatorPages`
 *
 * link templates in case you want to override one.
 *
 * @since 4.1.0
 */
export interface NgbPaginatorLinkContext {
    /**
     * Page number displayed by the current link.
     */
    currentPage: number;
    /**
     * If `true`, the current link is disabled.
     */
    disabled: boolean;
}
/**
 * A context for the `NgbPaginatorNumber` link template in case you want to override one.
 *
 * Extends `NgbPaginatorLinkContext`.
 *
 * @since 4.1.0
 */
export interface NgbPaginatorNumberContext extends NgbPaginatorLinkContext {
    /**
     * The page number, displayed by the current page link.
     */
    $implicit: number;
}
/**
 * A context for the `NgbPaginatorPages` pages template in case you want to override
 * the way all pages are displayed.
 *
 * @since 9.1.0
 */
export interface NgbPaginatorPagesContext {
    /**
     * The currently selected page number.
     */
    $implicit: number;
    /**
     * If `true`, pagination is disabled.
     */
    disabled: boolean;
    /**
     * Pages numbers that should be rendered starting with 1.
     */
    pages: number[];
}
/**
 * A directive to match the 'ellipsis' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorEllipsis {
    templateRef: TemplateRef<NgbPaginatorLinkContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorEllipsis, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorEllipsis, "ng-template[ngbPaginatorEllipsis]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the 'first' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorFirst {
    templateRef: TemplateRef<NgbPaginatorLinkContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorFirst, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorFirst, "ng-template[ngbPaginatorFirst]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the 'last' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorLast {
    templateRef: TemplateRef<NgbPaginatorLinkContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorLast, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorLast, "ng-template[ngbPaginatorLast]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the 'next' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorNext {
    templateRef: TemplateRef<NgbPaginatorLinkContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorNext, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorNext, "ng-template[ngbPaginatorNext]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the page 'number' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorNumber {
    templateRef: TemplateRef<NgbPaginatorNumberContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorNumberContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorNumber, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorNumber, "ng-template[ngbPaginatorNumber]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the 'previous' link template
 *
 * @since 4.1.0
 */
export declare class NgbPaginatorPrevious {
    templateRef: TemplateRef<NgbPaginatorLinkContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorPrevious, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorPrevious, "ng-template[ngbPaginatorPrevious]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive to match the 'pages' whole content
 *
 * @since 9.1.0
 */
export declare class NgbPaginatorPages {
    templateRef: TemplateRef<NgbPaginatorPagesContext>;
    constructor(templateRef: TemplateRef<NgbPaginatorPagesContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginatorPages, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbPaginatorPages, "ng-template[ngbPaginatorPages]", never, {}, {}, never, never, false, never>;
}
/** @docs-private */
declare const _NgbPaginatorBase: import("../core/constructor").Constructor<import("../core/disabled").CanDisable> & import("../core/constructor").AbstractConstructor<import("../core/disabled").CanDisable> & (new (...args: any[]) => import("../core/initialized").HasInitialized) & {
    new (): {};
};
/**
 * A component that displays page numbers and allows to customize them in several ways.
 */
export declare class NgbPaginator extends _NgbPaginatorBase implements OnInit, OnChanges {
    pageCount: number;
    pages: number[];
    private _initialized;
    tplEllipsis?: NgbPaginatorEllipsis;
    tplFirst?: NgbPaginatorFirst;
    tplLast?: NgbPaginatorLast;
    tplNext?: NgbPaginatorNext;
    tplNumber?: NgbPaginatorNumber;
    tplPrevious?: NgbPaginatorPrevious;
    tplPages?: NgbPaginatorPages;
    /**
     * If `true`, pagination links will be disabled.
     */
    disabled: boolean;
    /**
     * If `true`, the "First" and "Last" page links are shown.
     */
    boundaryLinks: boolean;
    /**
     * If `true`, the "Next" and "Previous" page links are shown.
     */
    directionLinks: boolean;
    /**
     * If `true`, the ellipsis symbols and first/last page numbers will be shown when `maxSize` > number of pages.
     */
    ellipses: boolean;
    /**
     * Whether to rotate pages when `maxSize` > number of pages.
     *
     * The current page always stays in the middle if `true`.
     */
    rotate: boolean;
    /**
     *  The number of items in your paginated collection.
     *
     *  Note, that this is not the number of pages. Page numbers are calculated dynamically based on
     *  `collectionSize` and `pageSize`. Ex. if you have 100 items in your collection and displaying 20 items per page,
     *  you'll end up with 5 pages.
     */
    collectionSize: number;
    /**
     *  The maximum number of pages to display.
     */
    maxSize: number;
    /**
     *  The current page.
     *
     *  Page numbers start with `1`.
     */
    page: number;
    /**
     *  The number of items per page.
     */
    pageSize: number;
    pageSizes: number[];
    /**
     *  An event fired when the page is changed. Will fire only if collection size is set and all values are valid.
     *
     *  Event payload is the number of the newly selected page.
     *
     *  Page numbers start with `1`.
     */
    pageChange: EventEmitter<number>;
    /**
     * The pagination display size.
     *
     * Bootstrap currently supports small and large sizes.
     */
    size?: 'sm' | 'lg' | string | null;
    constructor();
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    hasPrevious(): boolean;
    hasNext(): boolean;
    nextDisabled(): boolean;
    previousDisabled(): boolean;
    selectPage(pageNumber: number): void;
    isEllipsis(pageNumber: number): boolean;
    selectPageSize(): void;
    /**
     * Appends ellipses and first/last page number to the displayed pages
     */
    private _applyEllipses;
    /**
     * Rotates page numbers based on maxSize items visible.
     * Currently selected page stays in the middle:
     *
     * Ex. for selected page = 6:
     * [5,*6*,7] for maxSize = 3
     * [4,5,*6*,7] for maxSize = 4
     */
    private _applyRotation;
    /**
     * Paginates page numbers based on maxSize items per page.
     */
    private _applyPagination;
    private _setPageInRange;
    private _updatePages;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginator, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgbPaginator, "ngb-paginator", never, { "disabled": { "alias": "disabled"; "required": false; }; "boundaryLinks": { "alias": "boundaryLinks"; "required": false; }; "directionLinks": { "alias": "directionLinks"; "required": false; }; "ellipses": { "alias": "ellipses"; "required": false; }; "rotate": { "alias": "rotate"; "required": false; }; "collectionSize": { "alias": "collectionSize"; "required": false; }; "maxSize": { "alias": "maxSize"; "required": false; }; "page": { "alias": "page"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "pageSizes": { "alias": "pageSizes"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, { "pageChange": "pageChange"; }, ["tplEllipsis", "tplFirst", "tplLast", "tplNext", "tplNumber", "tplPrevious", "tplPages"], never, false, never>;
}
export {};
//# sourceMappingURL=pagination.d.ts.map